summaryrefslogtreecommitdiffstats
path: root/kexi/core/kexipart.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kexi/core/kexipart.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/core/kexipart.h')
-rw-r--r--kexi/core/kexipart.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kexi/core/kexipart.h b/kexi/core/kexipart.h
index 34136d83..f1168fd4 100644
--- a/kexi/core/kexipart.h
+++ b/kexi/core/kexipart.h
@@ -69,7 +69,7 @@ class KEXICORE_EXPORT Part : public TQObject
public:
/*! Constructor. */
- Part(TQObject *tqparent, const char *name, const TQStringList &);
+ Part(TQObject *parent, const char *name, const TQStringList &);
/*! Destructor. */
virtual ~Part();
@@ -148,9 +148,9 @@ class KEXICORE_EXPORT Part : public TQObject
Default implemention just returns empty KexiDialogTempData object. */
virtual KexiDialogTempData* createTempData(KexiDialogBase* dialog);
/*! Creates a new view for mode \a viewMode, \a item and \a tqparent. The view will be
used inside \a dialog. */
- virtual KexiViewBase* createView(TQWidget *tqparent, KexiDialogBase* dialog,
+ virtual KexiViewBase* createView(TQWidget *parent, KexiDialogBase* dialog,
KexiPart::Item &item, int viewMode = Kexi::DataViewMode, TQMap<TQString,TQString>* staticObjectArgs = 0) = 0;
/*! i18n'd instance name usable for displaying in gui as object's name.
@@ -213,7 +213,7 @@ class KEXICORE_EXPORT Part : public TQObject
protected:
//! Used by StaticPart
- Part(TQObject* tqparent, StaticInfo *info);
+ Part(TQObject* parent, StaticInfo *info);
// virtual KexiDialogBase* createInstance(KexiMainWindow *win, const KexiPart::Item &item, int viewMode = Kexi::DataViewMode) = 0;
@@ -148,9 +148,9 @@ class KEXICORE_EXPORT Part : public TQObject
Default implemention just returns empty KexiDialogTempData object. */
virtual KexiDialogTempData* createTempData(KexiDialogBase* dialog);
- /*! Creates a new view for mode \a viewMode, \a item and \a tqparent. The view will be
+ /*! Creates a new view for mode \a viewMode, \a item and \a parent. The view will be
used inside \a dialog. */